# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..arithmetic import MaskScalarVolume


def test_MaskScalarVolume_inputs():
    input_map = dict(
        InputVolume=dict(argstr="%s", extensions=None, position=-3,),
        MaskVolume=dict(argstr="%s", extensions=None, position=-2,),
        OutputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        label=dict(argstr="--label %d",),
        replace=dict(argstr="--replace %d",),
    )
    inputs = MaskScalarVolume.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MaskScalarVolume_outputs():
    output_map = dict(OutputVolume=dict(extensions=None, position=-1,),)
    outputs = MaskScalarVolume.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..tracking import Tracks2Prob


def test_Tracks2Prob_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        colour=dict(argstr="-colour", position=3,),
        environ=dict(nohash=True, usedefault=True,),
        fraction=dict(argstr="-fraction", position=3,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        out_filename=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        output_datatype=dict(argstr="-datatype %s", position=2,),
        resample=dict(argstr="-resample %d", position=3, units="mm",),
        template_file=dict(argstr="-template %s", extensions=None, position=1,),
        voxel_dims=dict(argstr="-vox %s", position=2, sep=",",),
    )
    inputs = Tracks2Prob.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Tracks2Prob_outputs():
    output_map = dict(tract_image=dict(extensions=None,),)
    outputs = Tracks2Prob.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import ANTS


def test_ANTS_inputs():
    input_map = dict(
        affine_gradient_descent_option=dict(argstr="%s",),
        args=dict(argstr="%s",),
        delta_time=dict(requires=["number_of_time_steps"],),
        dimension=dict(argstr="%d", position=1,),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(mandatory=True,),
        gradient_step_length=dict(requires=["transformation_model"],),
        metric=dict(mandatory=True,),
        metric_weight=dict(mandatory=True, requires=["metric"], usedefault=True,),
        mi_option=dict(argstr="--MI-option %s", sep="x",),
        moving_image=dict(argstr="%s", mandatory=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        number_of_affine_iterations=dict(
            argstr="--number-of-affine-iterations %s", sep="x",
        ),
        number_of_iterations=dict(argstr="--number-of-iterations %s", sep="x",),
        number_of_time_steps=dict(requires=["gradient_step_length"],),
        output_transform_prefix=dict(
            argstr="--output-naming %s", mandatory=True, usedefault=True,
        ),
        radius=dict(mandatory=True, requires=["metric"],),
        regularization=dict(argstr="%s",),
        regularization_deformation_field_sigma=dict(requires=["regularization"],),
        regularization_gradient_field_sigma=dict(requires=["regularization"],),
        smoothing_sigmas=dict(argstr="--gaussian-smoothing-sigmas %s", sep="x",),
        subsampling_factors=dict(argstr="--subsampling-factors %s", sep="x",),
        symmetry_type=dict(requires=["delta_time"],),
        transformation_model=dict(argstr="%s", mandatory=True,),
        use_histogram_matching=dict(argstr="%s", usedefault=True,),
    )
    inputs = ANTS.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ANTS_outputs():
    output_map = dict(
        affine_transform=dict(extensions=None,),
        inverse_warp_transform=dict(extensions=None,),
        metaheader=dict(extensions=None,),
        metaheader_raw=dict(extensions=None,),
        warp_transform=dict(extensions=None,),
    )
    outputs = ANTS.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import FWHMx


def test_FWHMx_inputs():
    input_map = dict(
        acf=dict(argstr="-acf", usedefault=True,),
        args=dict(argstr="%s",),
        arith=dict(argstr="-arith", xor=["geom"],),
        automask=dict(argstr="-automask", usedefault=True,),
        combine=dict(argstr="-combine",),
        compat=dict(argstr="-compat",),
        demed=dict(argstr="-demed", xor=["detrend"],),
        detrend=dict(argstr="-detrend", usedefault=True, xor=["demed"],),
        environ=dict(nohash=True, usedefault=True,),
        geom=dict(argstr="-geom", xor=["arith"],),
        in_file=dict(argstr="-input %s", extensions=None, mandatory=True,),
        mask=dict(argstr="-mask %s", extensions=None,),
        out_detrend=dict(
            argstr="-detprefix %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_detrend",
        ),
        out_file=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_fwhmx.out",
            position=-1,
        ),
        out_subbricks=dict(
            argstr="-out %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_subbricks.out",
        ),
        unif=dict(argstr="-unif",),
    )
    inputs = FWHMx.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FWHMx_outputs():
    output_map = dict(
        acf_param=dict(),
        fwhm=dict(),
        out_acf=dict(extensions=None,),
        out_detrend=dict(extensions=None,),
        out_file=dict(extensions=None,),
        out_subbricks=dict(extensions=None,),
    )
    outputs = FWHMx.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import HARDIMat


def test_HARDIMat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bvals=dict(extensions=None, mandatory=True,),
        bvecs=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        environ=dict(nohash=True, usedefault=True,),
        image_info=dict(argstr="-info %s", extensions=None,),
        image_orientation_vectors=dict(argstr="-iop %f",),
        oblique_correction=dict(argstr="-oc",),
        odf_file=dict(argstr="-odf %s", extensions=None,),
        order=dict(argstr="-order %s",),
        out_file=dict(argstr="%s", extensions=None, position=2, usedefault=True,),
        reference_file=dict(argstr="-ref %s", extensions=None,),
    )
    inputs = HARDIMat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_HARDIMat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = HARDIMat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..visualization import ConvertScalarImageToRGB


def test_ConvertScalarImageToRGB_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        colormap=dict(argstr="%s", mandatory=True, position=4,),
        custom_color_map_file=dict(argstr="%s", position=5, usedefault=True,),
        dimension=dict(argstr="%d", mandatory=True, position=0, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        input_image=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        mask_image=dict(argstr="%s", extensions=None, position=3, usedefault=True,),
        maximum_RGB_output=dict(argstr="%d", position=9, usedefault=True,),
        maximum_input=dict(argstr="%d", mandatory=True, position=7,),
        minimum_RGB_output=dict(argstr="%d", position=8, usedefault=True,),
        minimum_input=dict(argstr="%d", mandatory=True, position=6,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_image=dict(argstr="%s", position=2, usedefault=True,),
    )
    inputs = ConvertScalarImageToRGB.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ConvertScalarImageToRGB_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = ConvertScalarImageToRGB.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Volreg


def test_Volreg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        basefile=dict(argstr="-base %s", extensions=None, position=-6,),
        copyorigin=dict(argstr="-twodup",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        in_weight_volume=dict(argstr="-weight '%s[%d]'",),
        interp=dict(argstr="-%s",),
        md1d_file=dict(
            argstr="-maxdisp1D %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_md.1D",
            position=-4,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        oned_file=dict(
            argstr="-1Dfile %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s.1D",
        ),
        oned_matrix_save=dict(
            argstr="-1Dmatrix_save %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s.aff12.1D",
        ),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_volreg",
        ),
        outputtype=dict(),
        timeshift=dict(argstr="-tshift 0",),
        verbose=dict(argstr="-verbose",),
        zpad=dict(argstr="-zpad %d", position=-5,),
    )
    inputs = Volreg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Volreg_outputs():
    output_map = dict(
        md1d_file=dict(extensions=None,),
        oned_file=dict(extensions=None,),
        oned_matrix_save=dict(extensions=None,),
        out_file=dict(extensions=None,),
    )
    outputs = Volreg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmSPECTRE2010


def test_MedicAlgorithmSPECTRE2010_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inApply=dict(argstr="--inApply %s",),
        inAtlas=dict(argstr="--inAtlas %s", extensions=None,),
        inBackground=dict(argstr="--inBackground %f",),
        inCoarse=dict(argstr="--inCoarse %f",),
        inCost=dict(argstr="--inCost %s",),
        inDegrees=dict(argstr="--inDegrees %s",),
        inFind=dict(argstr="--inFind %s",),
        inFine=dict(argstr="--inFine %f",),
        inImage=dict(argstr="--inImage %s",),
        inInhomogeneity=dict(argstr="--inInhomogeneity %s",),
        inInitial=dict(argstr="--inInitial %d",),
        inInitial2=dict(argstr="--inInitial2 %f",),
        inInput=dict(argstr="--inInput %s", extensions=None,),
        inMMC=dict(argstr="--inMMC %d",),
        inMMC2=dict(argstr="--inMMC2 %d",),
        inMaximum=dict(argstr="--inMaximum %f",),
        inMinimum=dict(argstr="--inMinimum %f",),
        inMinimum2=dict(argstr="--inMinimum2 %f",),
        inMultiple=dict(argstr="--inMultiple %d",),
        inMultithreading=dict(argstr="--inMultithreading %s",),
        inNumber=dict(argstr="--inNumber %d",),
        inNumber2=dict(argstr="--inNumber2 %d",),
        inOutput=dict(argstr="--inOutput %s",),
        inOutput2=dict(argstr="--inOutput2 %s",),
        inOutput3=dict(argstr="--inOutput3 %s",),
        inOutput4=dict(argstr="--inOutput4 %s",),
        inOutput5=dict(argstr="--inOutput5 %s",),
        inRegistration=dict(argstr="--inRegistration %s",),
        inResample=dict(argstr="--inResample %s",),
        inRun=dict(argstr="--inRun %s",),
        inSkip=dict(argstr="--inSkip %s",),
        inSmoothing=dict(argstr="--inSmoothing %f",),
        inSubsample=dict(argstr="--inSubsample %s",),
        inUse=dict(argstr="--inUse %s",),
        null=dict(argstr="--null %s",),
        outFANTASM=dict(argstr="--outFANTASM %s", hash_files=False,),
        outMask=dict(argstr="--outMask %s", hash_files=False,),
        outMidsagittal=dict(argstr="--outMidsagittal %s", hash_files=False,),
        outOriginal=dict(argstr="--outOriginal %s", hash_files=False,),
        outPrior=dict(argstr="--outPrior %s", hash_files=False,),
        outSegmentation=dict(argstr="--outSegmentation %s", hash_files=False,),
        outSplitHalves=dict(argstr="--outSplitHalves %s", hash_files=False,),
        outStripped=dict(argstr="--outStripped %s", hash_files=False,),
        outd0=dict(argstr="--outd0 %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmSPECTRE2010.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmSPECTRE2010_outputs():
    output_map = dict(
        outFANTASM=dict(extensions=None,),
        outMask=dict(extensions=None,),
        outMidsagittal=dict(extensions=None,),
        outOriginal=dict(extensions=None,),
        outPrior=dict(extensions=None,),
        outSegmentation=dict(extensions=None,),
        outSplitHalves=dict(extensions=None,),
        outStripped=dict(extensions=None,),
        outd0=dict(extensions=None,),
    )
    outputs = MedicAlgorithmSPECTRE2010.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Denoise


def test_Denoise_inputs():
    input_map = dict(
        block_radius=dict(usedefault=True,),
        in_file=dict(extensions=None, mandatory=True,),
        in_mask=dict(extensions=None,),
        noise_mask=dict(extensions=None,),
        noise_model=dict(mandatory=True, usedefault=True,),
        patch_radius=dict(usedefault=True,),
        signal_mask=dict(extensions=None,),
        snr=dict(),
    )
    inputs = Denoise.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Denoise_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Denoise.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import SUSAN


def test_SUSAN_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        brightness_threshold=dict(argstr="%.10f", mandatory=True, position=2,),
        dimension=dict(argstr="%d", position=4, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fwhm=dict(argstr="%.10f", mandatory=True, position=3,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=-1,
        ),
        output_type=dict(),
        usans=dict(argstr="", position=6, usedefault=True,),
        use_median=dict(argstr="%d", position=5, usedefault=True,),
    )
    inputs = SUSAN.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SUSAN_outputs():
    output_map = dict(smoothed_file=dict(extensions=None,),)
    outputs = SUSAN.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..epi import Eddy


def test_Eddy_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cnr_maps=dict(argstr="--cnr_maps", min_ver="5.0.10",),
        dont_peas=dict(argstr="--dont_peas",),
        dont_sep_offs_move=dict(argstr="--dont_sep_offs_move",),
        environ=dict(nohash=True, usedefault=True,),
        estimate_move_by_susceptibility=dict(
            argstr="--estimate_move_by_susceptibility", min_ver="6.0.1",
        ),
        fep=dict(argstr="--fep",),
        field=dict(argstr="--field=%s", extensions=None,),
        field_mat=dict(argstr="--field_mat=%s", extensions=None,),
        flm=dict(argstr="--flm=%s", usedefault=True,),
        fudge_factor=dict(argstr="--ff=%s", usedefault=True,),
        fwhm=dict(argstr="--fwhm=%s",),
        in_acqp=dict(argstr="--acqp=%s", extensions=None, mandatory=True,),
        in_bval=dict(argstr="--bvals=%s", extensions=None, mandatory=True,),
        in_bvec=dict(argstr="--bvecs=%s", extensions=None, mandatory=True,),
        in_file=dict(argstr="--imain=%s", extensions=None, mandatory=True,),
        in_index=dict(argstr="--index=%s", extensions=None, mandatory=True,),
        in_mask=dict(argstr="--mask=%s", extensions=None, mandatory=True,),
        in_topup_fieldcoef=dict(
            argstr="--topup=%s", extensions=None, requires=["in_topup_movpar"],
        ),
        in_topup_movpar=dict(extensions=None, requires=["in_topup_fieldcoef"],),
        initrand=dict(argstr="--initrand", min_ver="5.0.10",),
        interp=dict(argstr="--interp=%s", usedefault=True,),
        is_shelled=dict(argstr="--data_is_shelled",),
        json=dict(
            argstr="--json=%s",
            min_ver="6.0.1",
            requires=["mporder"],
            xor=["slice_order"],
        ),
        mbs_ksp=dict(
            argstr="--mbs_ksp=%smm",
            min_ver="6.0.1",
            requires=["estimate_move_by_susceptibility"],
        ),
        mbs_lambda=dict(
            argstr="--mbs_lambda=%s",
            min_ver="6.0.1",
            requires=["estimate_move_by_susceptibility"],
        ),
        mbs_niter=dict(
            argstr="--mbs_niter=%s",
            min_ver="6.0.1",
            requires=["estimate_move_by_susceptibility"],
        ),
        method=dict(argstr="--resamp=%s", usedefault=True,),
        mporder=dict(argstr="--mporder=%s", min_ver="5.0.11", requires=["use_cuda"],),
        multiband_factor=dict(argstr="--mb=%s", min_ver="5.0.10",),
        multiband_offset=dict(
            argstr="--mb_offs=%d", min_ver="5.0.10", requires=["multiband_factor"],
        ),
        niter=dict(argstr="--niter=%s", usedefault=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        nvoxhp=dict(argstr="--nvoxhp=%s", usedefault=True,),
        out_base=dict(argstr="--out=%s", usedefault=True,),
        outlier_nstd=dict(argstr="--ol_nstd", min_ver="5.0.10", requires=["repol"],),
        outlier_nvox=dict(argstr="--ol_nvox", min_ver="5.0.10", requires=["repol"],),
        outlier_pos=dict(argstr="--ol_pos", min_ver="5.0.10", requires=["repol"],),
        outlier_sqr=dict(argstr="--ol_sqr", min_ver="5.0.10", requires=["repol"],),
        outlier_type=dict(argstr="--ol_type", min_ver="5.0.10", requires=["repol"],),
        output_type=dict(),
        repol=dict(argstr="--repol",),
        residuals=dict(argstr="--residuals", min_ver="5.0.10",),
        session=dict(argstr="--session=%s", extensions=None,),
        slice2vol_interp=dict(
            argstr="--s2v_interp=%s", min_ver="5.0.11", requires=["mporder"],
        ),
        slice2vol_lambda=dict(
            argstr="--s2v_lambda=%d", min_ver="5.0.11", requires=["mporder"],
        ),
        slice2vol_niter=dict(
            argstr="--s2v_niter=%d", min_ver="5.0.11", requires=["mporder"],
        ),
        slice_order=dict(
            argstr="--slspec=%s", min_ver="5.0.11", requires=["mporder"], xor=["json"],
        ),
        slm=dict(argstr="--slm=%s", usedefault=True,),
        use_cuda=dict(),
    )
    inputs = Eddy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Eddy_outputs():
    output_map = dict(
        out_cnr_maps=dict(extensions=None,),
        out_corrected=dict(extensions=None,),
        out_movement_over_time=dict(extensions=None,),
        out_movement_rms=dict(extensions=None,),
        out_outlier_free=dict(extensions=None,),
        out_outlier_map=dict(extensions=None,),
        out_outlier_n_sqr_stdev_map=dict(extensions=None,),
        out_outlier_n_stdev_map=dict(extensions=None,),
        out_outlier_report=dict(extensions=None,),
        out_parameter=dict(extensions=None,),
        out_residuals=dict(extensions=None,),
        out_restricted_movement_rms=dict(extensions=None,),
        out_rotated_bvecs=dict(extensions=None,),
        out_shell_alignment_parameters=dict(extensions=None,),
        out_shell_pe_translation_parameters=dict(extensions=None,),
    )
    outputs = Eddy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractTensor


def test_gtractTensor_inputs():
    input_map = dict(
        applyMeasurementFrame=dict(argstr="--applyMeasurementFrame ",),
        args=dict(argstr="%s",),
        b0Index=dict(argstr="--b0Index %d",),
        backgroundSuppressingThreshold=dict(
            argstr="--backgroundSuppressingThreshold %d",
        ),
        environ=dict(nohash=True, usedefault=True,),
        ignoreIndex=dict(argstr="--ignoreIndex %s", sep=",",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        maskProcessingMode=dict(argstr="--maskProcessingMode %s",),
        maskVolume=dict(argstr="--maskVolume %s", extensions=None,),
        medianFilterSize=dict(argstr="--medianFilterSize %s", sep=",",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        resampleIsotropic=dict(argstr="--resampleIsotropic ",),
        size=dict(argstr="--size %f",),
    )
    inputs = gtractTensor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractTensor_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = gtractTensor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FAST


def test_FAST_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bias_iters=dict(argstr="-I %d",),
        bias_lowpass=dict(argstr="-l %d", units="mm",),
        environ=dict(nohash=True, usedefault=True,),
        hyper=dict(argstr="-H %.2f",),
        img_type=dict(argstr="-t %d",),
        in_files=dict(argstr="%s", copyfile=False, mandatory=True, position=-1,),
        init_seg_smooth=dict(argstr="-f %.3f",),
        init_transform=dict(argstr="-a %s", extensions=None,),
        iters_afterbias=dict(argstr="-O %d",),
        manual_seg=dict(argstr="-s %s", extensions=None,),
        mixel_smooth=dict(argstr="-R %.2f",),
        no_bias=dict(argstr="-N",),
        no_pve=dict(argstr="--nopve",),
        number_classes=dict(argstr="-n %d",),
        other_priors=dict(argstr="-A %s",),
        out_basename=dict(argstr="-o %s", extensions=None,),
        output_biascorrected=dict(argstr="-B",),
        output_biasfield=dict(argstr="-b",),
        output_type=dict(),
        probability_maps=dict(argstr="-p",),
        segment_iters=dict(argstr="-W %d",),
        segments=dict(argstr="-g",),
        use_priors=dict(argstr="-P",),
        verbose=dict(argstr="-v",),
    )
    inputs = FAST.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FAST_outputs():
    output_map = dict(
        bias_field=dict(),
        mixeltype=dict(extensions=None,),
        partial_volume_files=dict(),
        partial_volume_map=dict(extensions=None,),
        probability_maps=dict(),
        restored_image=dict(),
        tissue_class_files=dict(),
        tissue_class_map=dict(extensions=None,),
    )
    outputs = FAST.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MRConvert


def test_MRConvert_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        extension=dict(position=2, usedefault=True,),
        extract_at_axis=dict(argstr="-coord %s", position=1,),
        extract_at_coordinate=dict(argstr="%s", position=2, sep=",",),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        layout=dict(argstr="-output %s", position=2,),
        offset_bias=dict(argstr="-scale %d", position=3, units="mm",),
        out_filename=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        output_datatype=dict(argstr="-output %s", position=2,),
        prs=dict(argstr="-prs", position=3,),
        replace_NaN_with_zero=dict(argstr="-zero", position=3,),
        resample=dict(argstr="-scale %d", position=3, units="mm",),
        voxel_dims=dict(argstr="-vox %s", position=3, sep=",",),
    )
    inputs = MRConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRConvert_outputs():
    output_map = dict(converted=dict(extensions=None,),)
    outputs = MRConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import SurfaceTransform


def test_SurfaceTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        hemi=dict(argstr="--hemi %s", mandatory=True,),
        out_file=dict(argstr="--tval %s", extensions=None, genfile=True,),
        reshape=dict(argstr="--reshape",),
        reshape_factor=dict(argstr="--reshape-factor",),
        source_annot_file=dict(
            argstr="--sval-annot %s",
            extensions=None,
            mandatory=True,
            xor=["source_file"],
        ),
        source_file=dict(
            argstr="--sval %s",
            extensions=None,
            mandatory=True,
            xor=["source_annot_file"],
        ),
        source_subject=dict(argstr="--srcsubject %s", mandatory=True,),
        source_type=dict(argstr="--sfmt %s", requires=["source_file"],),
        subjects_dir=dict(),
        target_ico_order=dict(argstr="--trgicoorder %d",),
        target_subject=dict(argstr="--trgsubject %s", mandatory=True,),
        target_type=dict(argstr="--tfmt %s",),
    )
    inputs = SurfaceTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SurfaceTransform_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SurfaceTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Warp


def test_Warp_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        deoblique=dict(argstr="-deoblique",),
        environ=dict(nohash=True, usedefault=True,),
        gridset=dict(argstr="-gridset %s", extensions=None,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        interp=dict(argstr="-%s",),
        matparent=dict(argstr="-matparent %s", extensions=None,),
        mni2tta=dict(argstr="-mni2tta",),
        newgrid=dict(argstr="-newgrid %f",),
        num_threads=dict(nohash=True, usedefault=True,),
        oblique_parent=dict(argstr="-oblique_parent %s", extensions=None,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_warp",
        ),
        outputtype=dict(),
        save_warp=dict(requires=["verbose"],),
        tta2mni=dict(argstr="-tta2mni",),
        verbose=dict(argstr="-verb",),
        zpad=dict(argstr="-zpad %d",),
    )
    inputs = Warp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Warp_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), warp_file=dict(extensions=None,),
    )
    outputs = Warp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FieldMap


def test_FieldMap_inputs():
    input_map = dict(
        anat_file=dict(copyfile=False, extensions=None, field="subj.anat",),
        blip_direction=dict(field="subj.defaults.defaultsval.blipdir", mandatory=True,),
        echo_times=dict(field="subj.defaults.defaultsval.et", mandatory=True,),
        epi_file=dict(
            copyfile=False, extensions=None, field="subj.session.epi", mandatory=True,
        ),
        epifm=dict(field="subj.defaults.defaultsval.epifm", usedefault=True,),
        jacobian_modulation=dict(
            field="subj.defaults.defaultsval.ajm", usedefault=True,
        ),
        jobtype=dict(usedefault=True,),
        magnitude_file=dict(
            copyfile=False,
            extensions=None,
            field="subj.data.presubphasemag.magnitude",
            mandatory=True,
        ),
        mask_fwhm=dict(field="subj.defaults.defaultsval.mflags.fwhm", usedefault=True,),
        maskbrain=dict(field="subj.defaults.defaultsval.maskbrain", usedefault=True,),
        matchanat=dict(field="subj.matchanat", usedefault=True,),
        matchvdm=dict(field="subj.matchvdm", usedefault=True,),
        matlab_cmd=dict(),
        method=dict(field="subj.defaults.defaultsval.uflags.method", usedefault=True,),
        mfile=dict(usedefault=True,),
        ndilate=dict(
            field="subj.defaults.defaultsval.mflags.ndilate", usedefault=True,
        ),
        nerode=dict(field="subj.defaults.defaultsval.mflags.nerode", usedefault=True,),
        pad=dict(field="subj.defaults.defaultsval.uflags.pad", usedefault=True,),
        paths=dict(),
        phase_file=dict(
            copyfile=False,
            extensions=None,
            field="subj.data.presubphasemag.phase",
            mandatory=True,
        ),
        reg=dict(field="subj.defaults.defaultsval.mflags.reg", usedefault=True,),
        sessname=dict(field="subj.sessname", usedefault=True,),
        template=dict(
            copyfile=False,
            extensions=None,
            field="subj.defaults.defaultsval.mflags.template",
        ),
        thresh=dict(field="subj.defaults.defaultsval.mflags.thresh", usedefault=True,),
        total_readout_time=dict(
            field="subj.defaults.defaultsval.tert", mandatory=True,
        ),
        unwarp_fwhm=dict(
            field="subj.defaults.defaultsval.uflags.fwhm", usedefault=True,
        ),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        writeunwarped=dict(field="subj.writeunwarped", usedefault=True,),
        ws=dict(field="subj.defaults.defaultsval.uflags.ws", usedefault=True,),
    )
    inputs = FieldMap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FieldMap_outputs():
    output_map = dict(vdm=dict(extensions=None,),)
    outputs = FieldMap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import AffineInitializer


def test_AffineInitializer_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="%s", position=0, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        local_search=dict(argstr="%d", position=7, usedefault=True,),
        moving_image=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="%s", extensions=None, position=3, usedefault=True,),
        principal_axes=dict(argstr="%d", position=6, usedefault=True,),
        radian_fraction=dict(argstr="%f", position=5, usedefault=True,),
        search_factor=dict(argstr="%f", position=4, usedefault=True,),
    )
    inputs = AffineInitializer.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AffineInitializer_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = AffineInitializer.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import RealignUnwarp


def test_RealignUnwarp_inputs():
    input_map = dict(
        est_basis_func=dict(field="uweoptions.basfcn",),
        est_first_order_effects=dict(field="uweoptions.fot",),
        est_jacobian_deformations=dict(field="uweoptions.jm",),
        est_num_of_iterations=dict(
            field="uweoptions.noi", maxlen=1, minlen=1, usedefault=True,
        ),
        est_re_est_mov_par=dict(field="uweoptions.rem",),
        est_reg_factor=dict(
            field="uweoptions.lambda", maxlen=1, minlen=1, usedefault=True,
        ),
        est_reg_order=dict(field="uweoptions.regorder",),
        est_second_order_effects=dict(field="uweoptions.sot",),
        est_taylor_expansion_point=dict(field="uweoptions.expround", usedefault=True,),
        est_unwarp_fwhm=dict(field="uweoptions.uwfwhm",),
        fwhm=dict(field="eoptions.fwhm",),
        in_files=dict(copyfile=True, field="data.scans", mandatory=True,),
        interp=dict(field="eoptions.einterp",),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        out_prefix=dict(field="uwroptions.prefix", usedefault=True,),
        paths=dict(),
        phase_map=dict(copyfile=False, extensions=None, field="data.pmscan",),
        quality=dict(field="eoptions.quality",),
        register_to_mean=dict(field="eoptions.rtm",),
        reslice_interp=dict(field="uwroptions.rinterp",),
        reslice_mask=dict(field="uwroptions.mask",),
        reslice_which=dict(
            field="uwroptions.uwwhich", maxlen=2, minlen=2, usedefault=True,
        ),
        reslice_wrap=dict(field="uwroptions.wrap",),
        separation=dict(field="eoptions.sep",),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        weight_img=dict(extensions=None, field="eoptions.weight",),
        wrap=dict(field="eoptions.ewrap",),
    )
    inputs = RealignUnwarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RealignUnwarp_outputs():
    output_map = dict(
        mean_image=dict(extensions=None,),
        modified_in_files=dict(),
        realigned_unwarped_files=dict(),
        realignment_parameters=dict(),
    )
    outputs = RealignUnwarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fix import Training


def test_Training_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        loo=dict(argstr="-l", position=2,),
        mel_icas=dict(argstr="%s", copyfile=False, position=-1,),
        trained_wts_filestem=dict(argstr="%s", position=1,),
    )
    inputs = Training.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Training_outputs():
    output_map = dict(trained_wts_file=dict(extensions=None,),)
    outputs = Training.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import MeasureImageSimilarity


def test_MeasureImageSimilarity_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="--dimensionality %d", position=1,),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(extensions=None, mandatory=True,),
        fixed_image_mask=dict(argstr="%s", extensions=None,),
        metric=dict(argstr="%s", mandatory=True,),
        metric_weight=dict(requires=["metric"], usedefault=True,),
        moving_image=dict(extensions=None, mandatory=True,),
        moving_image_mask=dict(extensions=None, requires=["fixed_image_mask"],),
        num_threads=dict(nohash=True, usedefault=True,),
        radius_or_number_of_bins=dict(mandatory=True, requires=["metric"],),
        sampling_percentage=dict(mandatory=True, requires=["metric"],),
        sampling_strategy=dict(requires=["metric"], usedefault=True,),
    )
    inputs = MeasureImageSimilarity.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MeasureImageSimilarity_outputs():
    output_map = dict(similarity=dict(),)
    outputs = MeasureImageSimilarity.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Synthesize


def test_Synthesize_inputs():
    input_map = dict(
        TR=dict(argstr="-TR %f",),
        args=dict(argstr="%s",),
        cbucket=dict(
            argstr="-cbucket %s", copyfile=False, extensions=None, mandatory=True,
        ),
        cenfill=dict(argstr="-cenfill %s",),
        dry_run=dict(argstr="-dry",),
        environ=dict(nohash=True, usedefault=True,),
        matrix=dict(
            argstr="-matrix %s", copyfile=False, extensions=None, mandatory=True,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="-prefix %s", extensions=None, name_template="syn",),
        outputtype=dict(),
        select=dict(argstr="-select %s", mandatory=True,),
    )
    inputs = Synthesize.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Synthesize_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Synthesize.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistLaminarProfileGeometry


def test_JistLaminarProfileGeometry_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inProfile=dict(argstr="--inProfile %s", extensions=None,),
        incomputed=dict(argstr="--incomputed %s",),
        inoutside=dict(argstr="--inoutside %f",),
        inregularization=dict(argstr="--inregularization %s",),
        insmoothing=dict(argstr="--insmoothing %f",),
        null=dict(argstr="--null %s",),
        outResult=dict(argstr="--outResult %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistLaminarProfileGeometry.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistLaminarProfileGeometry_outputs():
    output_map = dict(outResult=dict(extensions=None,),)
    outputs = JistLaminarProfileGeometry.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import ExpertAutomatedRegistration


def test_ExpertAutomatedRegistration_inputs():
    input_map = dict(
        affineMaxIterations=dict(argstr="--affineMaxIterations %d",),
        affineSamplingRatio=dict(argstr="--affineSamplingRatio %f",),
        args=dict(argstr="%s",),
        bsplineMaxIterations=dict(argstr="--bsplineMaxIterations %d",),
        bsplineSamplingRatio=dict(argstr="--bsplineSamplingRatio %f",),
        controlPointSpacing=dict(argstr="--controlPointSpacing %d",),
        environ=dict(nohash=True, usedefault=True,),
        expectedOffset=dict(argstr="--expectedOffset %f",),
        expectedRotation=dict(argstr="--expectedRotation %f",),
        expectedScale=dict(argstr="--expectedScale %f",),
        expectedSkew=dict(argstr="--expectedSkew %f",),
        fixedImage=dict(argstr="%s", extensions=None, position=-2,),
        fixedImageMask=dict(argstr="--fixedImageMask %s", extensions=None,),
        fixedLandmarks=dict(argstr="--fixedLandmarks %s...",),
        initialization=dict(argstr="--initialization %s",),
        interpolation=dict(argstr="--interpolation %s",),
        loadTransform=dict(argstr="--loadTransform %s", extensions=None,),
        metric=dict(argstr="--metric %s",),
        minimizeMemory=dict(argstr="--minimizeMemory ",),
        movingImage=dict(argstr="%s", extensions=None, position=-1,),
        movingLandmarks=dict(argstr="--movingLandmarks %s...",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        randomNumberSeed=dict(argstr="--randomNumberSeed %d",),
        registration=dict(argstr="--registration %s",),
        resampledImage=dict(argstr="--resampledImage %s", hash_files=False,),
        rigidMaxIterations=dict(argstr="--rigidMaxIterations %d",),
        rigidSamplingRatio=dict(argstr="--rigidSamplingRatio %f",),
        sampleFromOverlap=dict(argstr="--sampleFromOverlap ",),
        saveTransform=dict(argstr="--saveTransform %s", hash_files=False,),
        verbosityLevel=dict(argstr="--verbosityLevel %s",),
    )
    inputs = ExpertAutomatedRegistration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ExpertAutomatedRegistration_outputs():
    output_map = dict(
        resampledImage=dict(extensions=None,), saveTransform=dict(extensions=None,),
    )
    outputs = ExpertAutomatedRegistration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..bru2nii import Bru2


def test_Bru2_inputs():
    input_map = dict(
        actual_size=dict(argstr="-a",),
        append_protocol_name=dict(argstr="-p",),
        args=dict(argstr="%s",),
        compress=dict(argstr="-z",),
        environ=dict(nohash=True, usedefault=True,),
        force_conversion=dict(argstr="-f",),
        input_dir=dict(argstr="%s", mandatory=True, position=-1,),
        output_filename=dict(argstr="-o %s", genfile=True,),
    )
    inputs = Bru2.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Bru2_outputs():
    output_map = dict(nii_file=dict(extensions=None,),)
    outputs = Bru2.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..regutils import RegTools


def test_RegTools_inputs():
    input_map = dict(
        add_val=dict(argstr="-add %s",),
        args=dict(argstr="%s",),
        bin_flag=dict(argstr="-bin",),
        chg_res_val=dict(argstr="-chgres %f %f %f",),
        div_val=dict(argstr="-div %s",),
        down_flag=dict(argstr="-down",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True,),
        inter_val=dict(argstr="-interp %d",),
        iso_flag=dict(argstr="-iso",),
        mask_file=dict(argstr="-nan %s", extensions=None,),
        mul_val=dict(argstr="-mul %s",),
        noscl_flag=dict(argstr="-noscl",),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_tools.nii.gz",
        ),
        rms_val=dict(argstr="-rms %s", extensions=None,),
        smo_g_val=dict(argstr="-smoG %f %f %f",),
        smo_s_val=dict(argstr="-smoS %f %f %f",),
        sub_val=dict(argstr="-sub %s",),
        thr_val=dict(argstr="-thr %f",),
    )
    inputs = RegTools.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegTools_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = RegTools.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Notes


def test_Notes_inputs():
    input_map = dict(
        add=dict(argstr='-a "%s"',),
        add_history=dict(argstr='-h "%s"', xor=["rep_history"],),
        args=dict(argstr="%s",),
        delete=dict(argstr="-d %d",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="%s", extensions=None,),
        outputtype=dict(),
        rep_history=dict(argstr='-HH "%s"', xor=["add_history"],),
        ses=dict(argstr="-ses",),
    )
    inputs = Notes.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Notes_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Notes.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import QBallMX


def test_QBallMX_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        basistype=dict(argstr="-basistype %s", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        order=dict(argstr="-order %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        rbfpointset=dict(argstr="-rbfpointset %d", units="NA",),
        rbfsigma=dict(argstr="-rbfsigma %f", units="NA",),
        scheme_file=dict(argstr="-schemefile %s", extensions=None, mandatory=True,),
        smoothingsigma=dict(argstr="-smoothingsigma %f", units="NA",),
    )
    inputs = QBallMX.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_QBallMX_outputs():
    output_map = dict(qmat=dict(extensions=None,),)
    outputs = QBallMX.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import InvWarp


def test_InvWarp_inputs():
    input_map = dict(
        absolute=dict(argstr="--abs", xor=["relative"],),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inverse_warp=dict(
            argstr="--out=%s",
            extensions=None,
            hash_files=False,
            name_source=["warp"],
            name_template="%s_inverse",
        ),
        jacobian_max=dict(argstr="--jmax=%f",),
        jacobian_min=dict(argstr="--jmin=%f",),
        niter=dict(argstr="--niter=%d",),
        noconstraint=dict(argstr="--noconstraint",),
        output_type=dict(),
        reference=dict(argstr="--ref=%s", extensions=None, mandatory=True,),
        regularise=dict(argstr="--regularise=%f",),
        relative=dict(argstr="--rel", xor=["absolute"],),
        warp=dict(argstr="--warp=%s", extensions=None, mandatory=True,),
    )
    inputs = InvWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_InvWarp_outputs():
    output_map = dict(inverse_warp=dict(extensions=None,),)
    outputs = InvWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Slice


def test_Slice_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=0,
        ),
        out_base_name=dict(argstr="%s", position=1,),
        output_type=dict(),
    )
    inputs = Slice.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Slice_outputs():
    output_map = dict(out_files=dict(),)
    outputs = Slice.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import VecReg


def test_VecReg_inputs():
    input_map = dict(
        affine_mat=dict(argstr="-t %s", extensions=None,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True,),
        interpolation=dict(argstr="--interp=%s",),
        mask=dict(argstr="-m %s", extensions=None,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, hash_files=False,),
        output_type=dict(),
        ref_mask=dict(argstr="--refmask=%s", extensions=None,),
        ref_vol=dict(argstr="-r %s", extensions=None, mandatory=True,),
        rotation_mat=dict(argstr="--rotmat=%s", extensions=None,),
        rotation_warp=dict(argstr="--rotwarp=%s", extensions=None,),
        warp_field=dict(argstr="-w %s", extensions=None,),
    )
    inputs = VecReg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VecReg_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = VecReg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..tracking import Tractography


def test_Tractography_inputs():
    input_map = dict(
        act_file=dict(argstr="-act %s", extensions=None,),
        algorithm=dict(argstr="-algorithm %s", usedefault=True,),
        angle=dict(argstr="-angle %f",),
        args=dict(argstr="%s",),
        backtrack=dict(argstr="-backtrack",),
        bval_scale=dict(argstr="-bvalue_scaling %s",),
        crop_at_gmwmi=dict(argstr="-crop_at_gmwmi",),
        cutoff=dict(argstr="-cutoff %f",),
        cutoff_init=dict(argstr="-initcutoff %f",),
        downsample=dict(argstr="-downsample %f",),
        environ=dict(nohash=True, usedefault=True,),
        grad_file=dict(argstr="-grad %s", extensions=None, xor=["grad_fsl"],),
        grad_fsl=dict(argstr="-fslgrad %s %s", xor=["grad_file"],),
        in_bval=dict(extensions=None,),
        in_bvec=dict(argstr="-fslgrad %s %s", extensions=None,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        init_dir=dict(argstr="-initdirection %f,%f,%f",),
        max_length=dict(argstr="-maxlength %f",),
        max_seed_attempts=dict(argstr="-max_seed_attempts %d",),
        max_tracks=dict(argstr="-maxnum %d",),
        min_length=dict(argstr="-minlength %f",),
        n_samples=dict(argstr="-samples %d", usedefault=True,),
        n_tracks=dict(argstr="-number %d", max_ver="0.4",),
        n_trials=dict(argstr="-trials %d",),
        noprecompt=dict(argstr="-noprecomputed",),
        nthreads=dict(argstr="-nthreads %d", nohash=True,),
        out_file=dict(
            argstr="%s", extensions=None, mandatory=True, position=-1, usedefault=True,
        ),
        out_seeds=dict(argstr="-output_seeds %s", extensions=None, usedefault=True,),
        power=dict(argstr="-power %d",),
        roi_excl=dict(argstr="-exclude %s",),
        roi_incl=dict(argstr="-include %s",),
        roi_mask=dict(argstr="-mask %s",),
        seed_dynamic=dict(argstr="-seed_dynamic %s", extensions=None,),
        seed_gmwmi=dict(
            argstr="-seed_gmwmi %s", extensions=None, requires=["act_file"],
        ),
        seed_grid_voxel=dict(
            argstr="-seed_grid_per_voxel %s %d", xor=["seed_image", "seed_rnd_voxel"],
        ),
        seed_image=dict(argstr="-seed_image %s", extensions=None,),
        seed_rejection=dict(argstr="-seed_rejection %s", extensions=None,),
        seed_rnd_voxel=dict(
            argstr="-seed_random_per_voxel %s %d",
            xor=["seed_image", "seed_grid_voxel"],
        ),
        seed_sphere=dict(argstr="-seed_sphere %f,%f,%f,%f",),
        select=dict(argstr="-select %d", min_ver="3",),
        sph_trait=dict(argstr="%f,%f,%f,%f",),
        step_size=dict(argstr="-step %f",),
        stop=dict(argstr="-stop",),
        unidirectional=dict(argstr="-unidirectional",),
        use_rk4=dict(argstr="-rk4",),
    )
    inputs = Tractography.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Tractography_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), out_seeds=dict(extensions=None,),
    )
    outputs = Tractography.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import RobustRegister


def test_RobustRegister_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        auto_sens=dict(argstr="--satit", mandatory=True, xor=["outlier_sens"],),
        environ=dict(nohash=True, usedefault=True,),
        est_int_scale=dict(argstr="--iscale",),
        force_double=dict(argstr="--doubleprec",),
        force_float=dict(argstr="--floattype",),
        half_source=dict(argstr="--halfmov %s",),
        half_source_xfm=dict(argstr="--halfmovlta %s",),
        half_targ=dict(argstr="--halfdst %s",),
        half_targ_xfm=dict(argstr="--halfdstlta %s",),
        half_weights=dict(argstr="--halfweights %s",),
        high_iterations=dict(argstr="--highit %d",),
        in_xfm_file=dict(argstr="--transform", extensions=None,),
        init_orient=dict(argstr="--initorient",),
        iteration_thresh=dict(argstr="--epsit %.3f",),
        least_squares=dict(argstr="--leastsquares",),
        mask_source=dict(argstr="--maskmov %s", extensions=None,),
        mask_target=dict(argstr="--maskdst %s", extensions=None,),
        max_iterations=dict(argstr="--maxit %d",),
        no_init=dict(argstr="--noinit",),
        no_multi=dict(argstr="--nomulti",),
        out_reg_file=dict(argstr="--lta %s", usedefault=True,),
        outlier_limit=dict(argstr="--wlimit %.3f",),
        outlier_sens=dict(argstr="--sat %.4f", mandatory=True, xor=["auto_sens"],),
        registered_file=dict(argstr="--warp %s",),
        source_file=dict(argstr="--mov %s", extensions=None, mandatory=True,),
        subjects_dir=dict(),
        subsample_thresh=dict(argstr="--subsample %d",),
        target_file=dict(argstr="--dst %s", extensions=None, mandatory=True,),
        trans_only=dict(argstr="--transonly",),
        weights_file=dict(argstr="--weights %s",),
        write_vo2vox=dict(argstr="--vox2vox",),
    )
    inputs = RobustRegister.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RobustRegister_outputs():
    output_map = dict(
        half_source=dict(extensions=None,),
        half_source_xfm=dict(extensions=None,),
        half_targ=dict(extensions=None,),
        half_targ_xfm=dict(extensions=None,),
        half_weights=dict(extensions=None,),
        out_reg_file=dict(extensions=None,),
        registered_file=dict(extensions=None,),
        weights_file=dict(extensions=None,),
    )
    outputs = RobustRegister.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FUGUE


def test_FUGUE_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        asym_se_time=dict(argstr="--asym=%.10f",),
        despike_2dfilter=dict(argstr="--despike",),
        despike_threshold=dict(argstr="--despikethreshold=%s",),
        dwell_time=dict(argstr="--dwell=%.10f",),
        dwell_to_asym_ratio=dict(argstr="--dwelltoasym=%.10f",),
        environ=dict(nohash=True, usedefault=True,),
        fmap_in_file=dict(argstr="--loadfmap=%s", extensions=None,),
        fmap_out_file=dict(argstr="--savefmap=%s", extensions=None,),
        forward_warping=dict(usedefault=True,),
        fourier_order=dict(argstr="--fourier=%d",),
        icorr=dict(argstr="--icorr", requires=["shift_in_file"],),
        icorr_only=dict(argstr="--icorronly", requires=["unwarped_file"],),
        in_file=dict(argstr="--in=%s", extensions=None,),
        mask_file=dict(argstr="--mask=%s", extensions=None,),
        median_2dfilter=dict(argstr="--median",),
        no_extend=dict(argstr="--noextend",),
        no_gap_fill=dict(argstr="--nofill",),
        nokspace=dict(argstr="--nokspace",),
        output_type=dict(),
        pava=dict(argstr="--pava",),
        phase_conjugate=dict(argstr="--phaseconj",),
        phasemap_in_file=dict(argstr="--phasemap=%s", extensions=None,),
        poly_order=dict(argstr="--poly=%d",),
        save_fmap=dict(xor=["save_unmasked_fmap"],),
        save_shift=dict(xor=["save_unmasked_shift"],),
        save_unmasked_fmap=dict(argstr="--unmaskfmap", xor=["save_fmap"],),
        save_unmasked_shift=dict(argstr="--unmaskshift", xor=["save_shift"],),
        shift_in_file=dict(argstr="--loadshift=%s", extensions=None,),
        shift_out_file=dict(argstr="--saveshift=%s", extensions=None,),
        smooth2d=dict(argstr="--smooth2=%.2f",),
        smooth3d=dict(argstr="--smooth3=%.2f",),
        unwarp_direction=dict(argstr="--unwarpdir=%s",),
        unwarped_file=dict(
            argstr="--unwarp=%s",
            extensions=None,
            requires=["in_file"],
            xor=["warped_file"],
        ),
        warped_file=dict(
            argstr="--warp=%s",
            extensions=None,
            requires=["in_file"],
            xor=["unwarped_file"],
        ),
    )
    inputs = FUGUE.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FUGUE_outputs():
    output_map = dict(
        fmap_out_file=dict(extensions=None,),
        shift_out_file=dict(extensions=None,),
        unwarped_file=dict(extensions=None,),
        warped_file=dict(extensions=None,),
    )
    outputs = FUGUE.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import MakeDyadicVectors


def test_MakeDyadicVectors_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        mask=dict(argstr="%s", extensions=None, position=2,),
        output=dict(
            argstr="%s", extensions=None, hash_files=False, position=3, usedefault=True,
        ),
        output_type=dict(),
        perc=dict(argstr="%f", position=4,),
        phi_vol=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        theta_vol=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
    )
    inputs = MakeDyadicVectors.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MakeDyadicVectors_outputs():
    output_map = dict(dispersion=dict(extensions=None,), dyads=dict(extensions=None,),)
    outputs = MakeDyadicVectors.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import DWIRicianLMMSEFilter


def test_DWIRicianLMMSEFilter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        compressOutput=dict(argstr="--compressOutput ",),
        environ=dict(nohash=True, usedefault=True,),
        hrf=dict(argstr="--hrf %f",),
        inputVolume=dict(argstr="%s", extensions=None, position=-2,),
        iter=dict(argstr="--iter %d",),
        maxnstd=dict(argstr="--maxnstd %d",),
        minnstd=dict(argstr="--minnstd %d",),
        mnve=dict(argstr="--mnve %d",),
        mnvf=dict(argstr="--mnvf %d",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        re=dict(argstr="--re %s", sep=",",),
        rf=dict(argstr="--rf %s", sep=",",),
        uav=dict(argstr="--uav ",),
    )
    inputs = DWIRicianLMMSEFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWIRicianLMMSEFilter_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = DWIRicianLMMSEFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ExtractROI


def test_ExtractROI_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        crop_list=dict(
            argstr="%s",
            position=2,
            xor=[
                "x_min",
                "x_size",
                "y_min",
                "y_size",
                "z_min",
                "z_size",
                "t_min",
                "t_size",
            ],
        ),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        output_type=dict(),
        roi_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=1,
        ),
        t_min=dict(argstr="%d", position=8,),
        t_size=dict(argstr="%d", position=9,),
        x_min=dict(argstr="%d", position=2,),
        x_size=dict(argstr="%d", position=3,),
        y_min=dict(argstr="%d", position=4,),
        y_size=dict(argstr="%d", position=5,),
        z_min=dict(argstr="%d", position=6,),
        z_size=dict(argstr="%d", position=7,),
    )
    inputs = ExtractROI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ExtractROI_outputs():
    output_map = dict(roi_file=dict(extensions=None,),)
    outputs = ExtractROI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import TensorMetrics


def test_TensorMetrics_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        component=dict(argstr="-num %s", sep=",", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        in_mask=dict(argstr="-mask %s", extensions=None,),
        modulate=dict(argstr="-modulate %s",),
        out_adc=dict(argstr="-adc %s", extensions=None,),
        out_eval=dict(argstr="-value %s", extensions=None,),
        out_evec=dict(argstr="-vector %s", extensions=None,),
        out_fa=dict(argstr="-fa %s", extensions=None,),
    )
    inputs = TensorMetrics.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TensorMetrics_outputs():
    output_map = dict(
        out_adc=dict(extensions=None,),
        out_eval=dict(extensions=None,),
        out_evec=dict(extensions=None,),
        out_fa=dict(extensions=None,),
    )
    outputs = TensorMetrics.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import VtkStreamlines


def test_VtkStreamlines_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        colourorient=dict(argstr="-colourorient",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr=" < %s", extensions=None, mandatory=True, position=-2,),
        inputmodel=dict(argstr="-inputmodel %s", usedefault=True,),
        interpolate=dict(argstr="-interpolate",),
        interpolatescalars=dict(argstr="-interpolatescalars",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        scalar_file=dict(argstr="-scalarfile %s", extensions=None, position=3,),
        seed_file=dict(argstr="-seedfile %s", extensions=None, position=1,),
        target_file=dict(argstr="-targetfile %s", extensions=None, position=2,),
        voxeldims=dict(argstr="-voxeldims %s", position=4, units="mm",),
    )
    inputs = VtkStreamlines.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VtkStreamlines_outputs():
    output_map = dict(vtk=dict(extensions=None,),)
    outputs = VtkStreamlines.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import WarpUtils


def test_WarpUtils_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True,),
        knot_space=dict(argstr="--knotspace=%d,%d,%d",),
        out_file=dict(
            argstr="--out=%s",
            extensions=None,
            name_source=["in_file"],
            output_name="out_file",
            position=-1,
        ),
        out_format=dict(argstr="--outformat=%s",),
        out_jacobian=dict(argstr="--jac=%s", extensions=None,),
        output_type=dict(),
        reference=dict(argstr="--ref=%s", extensions=None, mandatory=True,),
        warp_resolution=dict(argstr="--warpres=%0.4f,%0.4f,%0.4f",),
        with_affine=dict(argstr="--withaff",),
        write_jacobian=dict(mandatory=True, usedefault=True,),
    )
    inputs = WarpUtils.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WarpUtils_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), out_jacobian=dict(extensions=None,),
    )
    outputs = WarpUtils.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..vista import VtoMat


def test_VtoMat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True, position=1,),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s.mat",
            position=-1,
        ),
    )
    inputs = VtoMat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VtoMat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = VtoMat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import BET


def test_BET_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        center=dict(argstr="-c %s", units="voxels",),
        environ=dict(nohash=True, usedefault=True,),
        frac=dict(argstr="-f %.2f",),
        functional=dict(
            argstr="-F",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        mask=dict(argstr="-m",),
        mesh=dict(argstr="-e",),
        no_output=dict(argstr="-n",),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=1,
        ),
        outline=dict(argstr="-o",),
        output_type=dict(),
        padding=dict(
            argstr="-Z",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        radius=dict(argstr="-r %d", units="mm",),
        reduce_bias=dict(
            argstr="-B",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        remove_eyes=dict(
            argstr="-S",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        robust=dict(
            argstr="-R",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        skull=dict(argstr="-s",),
        surfaces=dict(
            argstr="-A",
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        t2_guided=dict(
            argstr="-A2 %s",
            extensions=None,
            xor=(
                "functional",
                "reduce_bias",
                "robust",
                "padding",
                "remove_eyes",
                "surfaces",
                "t2_guided",
            ),
        ),
        threshold=dict(argstr="-t",),
        vertical_gradient=dict(argstr="-g %.2f",),
    )
    inputs = BET.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BET_outputs():
    output_map = dict(
        inskull_mask_file=dict(extensions=None,),
        inskull_mesh_file=dict(extensions=None,),
        mask_file=dict(extensions=None,),
        meshfile=dict(extensions=None,),
        out_file=dict(extensions=None,),
        outline_file=dict(extensions=None,),
        outskin_mask_file=dict(extensions=None,),
        outskin_mesh_file=dict(extensions=None,),
        outskull_mask_file=dict(extensions=None,),
        outskull_mesh_file=dict(extensions=None,),
        skull_file=dict(extensions=None,),
        skull_mask_file=dict(extensions=None,),
    )
    outputs = BET.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..confounds import ACompCor


def test_ACompCor_inputs():
    input_map = dict(
        components_file=dict(usedefault=True,),
        failure_mode=dict(usedefault=True,),
        header_prefix=dict(),
        high_pass_cutoff=dict(usedefault=True,),
        ignore_initial_volumes=dict(usedefault=True,),
        mask_files=dict(),
        mask_index=dict(requires=["mask_files"], xor=["merge_method"],),
        mask_names=dict(),
        merge_method=dict(requires=["mask_files"], xor=["mask_index"],),
        num_components=dict(xor=["variance_threshold"],),
        pre_filter=dict(usedefault=True,),
        realigned_file=dict(extensions=None, mandatory=True,),
        regress_poly_degree=dict(usedefault=True,),
        repetition_time=dict(),
        save_metadata=dict(usedefault=True,),
        save_pre_filter=dict(usedefault=True,),
        use_regress_poly=dict(deprecated="0.15.0", new_name="pre_filter",),
        variance_threshold=dict(xor=["num_components"],),
    )
    inputs = ACompCor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ACompCor_outputs():
    output_map = dict(
        components_file=dict(extensions=None,),
        metadata_file=dict(extensions=None,),
        pre_filter_file=dict(extensions=None,),
    )
    outputs = ACompCor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fibertrack import fibertrack


def test_fibertrack_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        forbidden_label=dict(argstr="--forbidden_label %d",),
        force=dict(argstr="--force ",),
        input_roi_file=dict(argstr="--input_roi_file %s", extensions=None,),
        input_tensor_file=dict(argstr="--input_tensor_file %s", extensions=None,),
        max_angle=dict(argstr="--max_angle %f",),
        min_fa=dict(argstr="--min_fa %f",),
        output_fiber_file=dict(argstr="--output_fiber_file %s", hash_files=False,),
        really_verbose=dict(argstr="--really_verbose ",),
        source_label=dict(argstr="--source_label %d",),
        step_size=dict(argstr="--step_size %f",),
        target_label=dict(argstr="--target_label %d",),
        verbose=dict(argstr="--verbose ",),
        whole_brain=dict(argstr="--whole_brain ",),
    )
    inputs = fibertrack.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_fibertrack_outputs():
    output_map = dict(output_fiber_file=dict(extensions=None,),)
    outputs = fibertrack.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTIFit


def test_DTIFit_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        base_name=dict(argstr="-o %s", position=1, usedefault=True,),
        bvals=dict(argstr="-b %s", extensions=None, mandatory=True, position=4,),
        bvecs=dict(argstr="-r %s", extensions=None, mandatory=True, position=3,),
        cni=dict(argstr="--cni=%s", extensions=None,),
        dwi=dict(argstr="-k %s", extensions=None, mandatory=True, position=0,),
        environ=dict(nohash=True, usedefault=True,),
        gradnonlin=dict(argstr="--gradnonlin=%s", extensions=None,),
        little_bit=dict(argstr="--littlebit",),
        mask=dict(argstr="-m %s", extensions=None, mandatory=True, position=2,),
        max_x=dict(argstr="-X %d",),
        max_y=dict(argstr="-Y %d",),
        max_z=dict(argstr="-Z %d",),
        min_x=dict(argstr="-x %d",),
        min_y=dict(argstr="-y %d",),
        min_z=dict(argstr="-z %d",),
        output_type=dict(),
        save_tensor=dict(argstr="--save_tensor",),
        sse=dict(argstr="--sse",),
    )
    inputs = DTIFit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTIFit_outputs():
    output_map = dict(
        FA=dict(extensions=None,),
        L1=dict(extensions=None,),
        L2=dict(extensions=None,),
        L3=dict(extensions=None,),
        MD=dict(extensions=None,),
        MO=dict(extensions=None,),
        S0=dict(extensions=None,),
        V1=dict(extensions=None,),
        V2=dict(extensions=None,),
        V3=dict(extensions=None,),
        sse=dict(extensions=None,),
        tensor=dict(extensions=None,),
    )
    outputs = DTIFit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import BestLinReg


def test_BestLinReg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        output_mnc=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            keep_extension=False,
            name_source=["source"],
            name_template="%s_bestlinreg.mnc",
            position=-1,
        ),
        output_xfm=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            keep_extension=False,
            name_source=["source"],
            name_template="%s_bestlinreg.xfm",
            position=-2,
        ),
        source=dict(argstr="%s", extensions=None, mandatory=True, position=-4,),
        target=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        verbose=dict(argstr="-verbose",),
    )
    inputs = BestLinReg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BestLinReg_outputs():
    output_map = dict(
        output_mnc=dict(extensions=None,), output_xfm=dict(extensions=None,),
    )
    outputs = BestLinReg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import AlignEpiAnatPy


def test_AlignEpiAnatPy_inputs():
    input_map = dict(
        anat=dict(argstr="-anat %s", copyfile=False, extensions=None, mandatory=True,),
        anat2epi=dict(argstr="-anat2epi",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        epi2anat=dict(argstr="-epi2anat",),
        epi_base=dict(argstr="-epi_base %s", mandatory=True,),
        epi_strip=dict(argstr="-epi_strip %s",),
        in_file=dict(
            argstr="-epi %s", copyfile=False, extensions=None, mandatory=True,
        ),
        outputtype=dict(),
        py27_path=dict(usedefault=True,),
        save_skullstrip=dict(argstr="-save_skullstrip",),
        suffix=dict(argstr="-suffix %s", usedefault=True,),
        tshift=dict(argstr="-tshift %s", usedefault=True,),
        volreg=dict(argstr="-volreg %s", usedefault=True,),
    )
    inputs = AlignEpiAnatPy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AlignEpiAnatPy_outputs():
    output_map = dict(
        anat_al_mat=dict(extensions=None,),
        anat_al_orig=dict(extensions=None,),
        epi_al_mat=dict(extensions=None,),
        epi_al_orig=dict(extensions=None,),
        epi_al_tlrc_mat=dict(extensions=None,),
        epi_reg_al_mat=dict(extensions=None,),
        epi_tlrc_al=dict(extensions=None,),
        epi_vr_al_mat=dict(extensions=None,),
        epi_vr_motion=dict(extensions=None,),
        skullstrip=dict(extensions=None,),
    )
    outputs = AlignEpiAnatPy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MRIsCalc


def test_MRIsCalc_inputs():
    input_map = dict(
        action=dict(argstr="%s", mandatory=True, position=-2,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file1=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        in_file2=dict(
            argstr="%s", extensions=None, position=-1, xor=["in_float", "in_int"],
        ),
        in_float=dict(argstr="%f", position=-1, xor=["in_file2", "in_int"],),
        in_int=dict(argstr="%d", position=-1, xor=["in_file2", "in_float"],),
        out_file=dict(argstr="-o %s", extensions=None, mandatory=True,),
        subjects_dir=dict(),
    )
    inputs = MRIsCalc.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIsCalc_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MRIsCalc.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractCostFastMarching


def test_gtractCostFastMarching_inputs():
    input_map = dict(
        anisotropyWeight=dict(argstr="--anisotropyWeight %f",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputAnisotropyVolume=dict(
            argstr="--inputAnisotropyVolume %s", extensions=None,
        ),
        inputStartingSeedsLabelMapVolume=dict(
            argstr="--inputStartingSeedsLabelMapVolume %s", extensions=None,
        ),
        inputTensorVolume=dict(argstr="--inputTensorVolume %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputCostVolume=dict(argstr="--outputCostVolume %s", hash_files=False,),
        outputSpeedVolume=dict(argstr="--outputSpeedVolume %s", hash_files=False,),
        seedThreshold=dict(argstr="--seedThreshold %f",),
        startingSeedsLabel=dict(argstr="--startingSeedsLabel %d",),
        stoppingValue=dict(argstr="--stoppingValue %f",),
    )
    inputs = gtractCostFastMarching.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractCostFastMarching_outputs():
    output_map = dict(
        outputCostVolume=dict(extensions=None,),
        outputSpeedVolume=dict(extensions=None,),
    )
    outputs = gtractCostFastMarching.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ABoverlap


def test_ABoverlap_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file_a=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-3,
        ),
        in_file_b=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-2,
        ),
        no_automask=dict(argstr="-no_automask",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr=" |& tee %s", extensions=None, position=-1,),
        outputtype=dict(),
        quiet=dict(argstr="-quiet",),
        verb=dict(argstr="-verb",),
    )
    inputs = ABoverlap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ABoverlap_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ABoverlap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import MRTrix2TrackVis


def test_MRTrix2TrackVis_inputs():
    input_map = dict(
        image_file=dict(extensions=None,),
        in_file=dict(extensions=None, mandatory=True,),
        matrix_file=dict(extensions=None,),
        out_filename=dict(extensions=None, genfile=True, usedefault=True,),
        registration_image_file=dict(extensions=None,),
    )
    inputs = MRTrix2TrackVis.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRTrix2TrackVis_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MRTrix2TrackVis.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..epi import EPIDeWarp


def test_EPIDeWarp_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cleanup=dict(argstr="--cleanup",),
        dph_file=dict(argstr="--dph %s", extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        epi_file=dict(argstr="--epi %s", extensions=None,),
        epidw=dict(argstr="--epidw %s", genfile=False,),
        esp=dict(argstr="--esp %s", usedefault=True,),
        exf_file=dict(argstr="--exf %s", extensions=None,),
        exfdw=dict(argstr="--exfdw %s", genfile=True,),
        mag_file=dict(argstr="--mag %s", extensions=None, mandatory=True, position=0,),
        nocleanup=dict(argstr="--nocleanup", usedefault=True,),
        output_type=dict(),
        sigma=dict(argstr="--sigma %s", usedefault=True,),
        tediff=dict(argstr="--tediff %s", usedefault=True,),
        tmpdir=dict(argstr="--tmpdir %s", genfile=True,),
        vsm=dict(argstr="--vsm %s", genfile=True,),
    )
    inputs = EPIDeWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EPIDeWarp_outputs():
    output_map = dict(
        exf_mask=dict(extensions=None,),
        exfdw=dict(extensions=None,),
        unwarped_file=dict(extensions=None,),
        vsm_file=dict(extensions=None,),
    )
    outputs = EPIDeWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import CalcCoregAffine


def test_CalcCoregAffine_inputs():
    input_map = dict(
        invmat=dict(extensions=None,),
        mat=dict(extensions=None,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        moving=dict(copyfile=False, extensions=None, mandatory=True,),
        paths=dict(),
        target=dict(extensions=None, mandatory=True,),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
    )
    inputs = CalcCoregAffine.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CalcCoregAffine_outputs():
    output_map = dict(invmat=dict(extensions=None,), mat=dict(extensions=None,),)
    outputs = CalcCoregAffine.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import ComputeTensorTrace


def test_ComputeTensorTrace_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="< %s", extensions=None, mandatory=True, position=1,),
        inputdatatype=dict(argstr="-inputdatatype %s",),
        inputmodel=dict(argstr="-inputmodel %s",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        outputdatatype=dict(argstr="-outputdatatype %s",),
        scheme_file=dict(argstr="%s", extensions=None, position=2,),
    )
    inputs = ComputeTensorTrace.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ComputeTensorTrace_outputs():
    output_map = dict(trace=dict(extensions=None,),)
    outputs = ComputeTensorTrace.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Concatenate


def test_Concatenate_inputs():
    input_map = dict(
        add_val=dict(argstr="--add %f",),
        args=dict(argstr="%s",),
        combine=dict(argstr="--combine",),
        concatenated_file=dict(argstr="--o %s", extensions=None, genfile=True,),
        environ=dict(nohash=True, usedefault=True,),
        gmean=dict(argstr="--gmean %d",),
        in_files=dict(argstr="--i %s...", mandatory=True,),
        keep_dtype=dict(argstr="--keep-datatype",),
        mask_file=dict(argstr="--mask %s", extensions=None,),
        max_bonfcor=dict(argstr="--max-bonfcor",),
        max_index=dict(argstr="--max-index",),
        mean_div_n=dict(argstr="--mean-div-n",),
        multiply_by=dict(argstr="--mul %f",),
        multiply_matrix_file=dict(argstr="--mtx %s", extensions=None,),
        paired_stats=dict(argstr="--paired-%s",),
        sign=dict(argstr="--%s",),
        sort=dict(argstr="--sort",),
        stats=dict(argstr="--%s",),
        subjects_dir=dict(),
        vote=dict(argstr="--vote",),
    )
    inputs = Concatenate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Concatenate_outputs():
    output_map = dict(concatenated_file=dict(extensions=None,),)
    outputs = Concatenate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..surface import ModelMaker


def test_ModelMaker_inputs():
    input_map = dict(
        InputVolume=dict(argstr="%s", extensions=None, position=-1,),
        args=dict(argstr="%s",),
        color=dict(argstr="--color %s", extensions=None,),
        debug=dict(argstr="--debug ",),
        decimate=dict(argstr="--decimate %f",),
        end=dict(argstr="--end %d",),
        environ=dict(nohash=True, usedefault=True,),
        filtertype=dict(argstr="--filtertype %s",),
        generateAll=dict(argstr="--generateAll ",),
        jointsmooth=dict(argstr="--jointsmooth ",),
        labels=dict(argstr="--labels %s", sep=",",),
        modelSceneFile=dict(argstr="--modelSceneFile %s...", hash_files=False,),
        name=dict(argstr="--name %s",),
        pad=dict(argstr="--pad ",),
        pointnormals=dict(argstr="--pointnormals ",),
        saveIntermediateModels=dict(argstr="--saveIntermediateModels ",),
        skipUnNamed=dict(argstr="--skipUnNamed ",),
        smooth=dict(argstr="--smooth %d",),
        splitnormals=dict(argstr="--splitnormals ",),
        start=dict(argstr="--start %d",),
    )
    inputs = ModelMaker.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ModelMaker_outputs():
    output_map = dict(modelSceneFile=dict(),)
    outputs = ModelMaker.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import BRAINSTalairach


def test_BRAINSTalairach_inputs():
    input_map = dict(
        AC=dict(argstr="--AC %s", sep=",",),
        ACisIndex=dict(argstr="--ACisIndex ",),
        IRP=dict(argstr="--IRP %s", sep=",",),
        IRPisIndex=dict(argstr="--IRPisIndex ",),
        PC=dict(argstr="--PC %s", sep=",",),
        PCisIndex=dict(argstr="--PCisIndex ",),
        SLA=dict(argstr="--SLA %s", sep=",",),
        SLAisIndex=dict(argstr="--SLAisIndex ",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        outputBox=dict(argstr="--outputBox %s", hash_files=False,),
        outputGrid=dict(argstr="--outputGrid %s", hash_files=False,),
    )
    inputs = BRAINSTalairach.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSTalairach_outputs():
    output_map = dict(
        outputBox=dict(extensions=None,), outputGrid=dict(extensions=None,),
    )
    outputs = BRAINSTalairach.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import CARegister


def test_CARegister_inputs():
    input_map = dict(
        A=dict(argstr="-A %d",),
        align=dict(argstr="-align-%s",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        invert_and_save=dict(argstr="-invert-and-save", position=-4,),
        l_files=dict(argstr="-l %s",),
        levels=dict(argstr="-levels %d",),
        mask=dict(argstr="-mask %s", extensions=None,),
        no_big_ventricles=dict(argstr="-nobigventricles",),
        num_threads=dict(),
        out_file=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        subjects_dir=dict(),
        template=dict(argstr="%s", extensions=None, position=-2,),
        transform=dict(argstr="-T %s", extensions=None,),
    )
    inputs = CARegister.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CARegister_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = CARegister.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..petstandarduptakevaluecomputation import PETStandardUptakeValueComputation


def test_PETStandardUptakeValueComputation_inputs():
    input_map = dict(
        OutputLabel=dict(argstr="--OutputLabel %s",),
        OutputLabelValue=dict(argstr="--OutputLabelValue %s",),
        SUVMax=dict(argstr="--SUVMax %s",),
        SUVMean=dict(argstr="--SUVMean %s",),
        SUVMin=dict(argstr="--SUVMin %s",),
        args=dict(argstr="%s",),
        color=dict(argstr="--color %s", extensions=None,),
        csvFile=dict(argstr="--csvFile %s", hash_files=False,),
        environ=dict(nohash=True, usedefault=True,),
        labelMap=dict(argstr="--labelMap %s", extensions=None,),
        petDICOMPath=dict(argstr="--petDICOMPath %s",),
        petVolume=dict(argstr="--petVolume %s", extensions=None,),
    )
    inputs = PETStandardUptakeValueComputation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PETStandardUptakeValueComputation_outputs():
    output_map = dict(csvFile=dict(extensions=None,),)
    outputs = PETStandardUptakeValueComputation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..em import EM


def test_EM_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bc_order_val=dict(argstr="-bc_order %s", usedefault=True,),
        bc_thresh_val=dict(argstr="-bc_thresh %s", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True, position=4,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        max_iter=dict(argstr="-max_iter %s", usedefault=True,),
        min_iter=dict(argstr="-min_iter %s", usedefault=True,),
        mrf_beta_val=dict(argstr="-mrf_beta %s",),
        no_prior=dict(
            argstr="-nopriors %s", mandatory=True, xor=["prior_4D", "priors"],
        ),
        out_bc_file=dict(
            argstr="-bc_out %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_bc_em.nii.gz",
        ),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_em.nii.gz",
        ),
        out_outlier_file=dict(
            argstr="-out_outlier %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_outlier_em.nii.gz",
        ),
        outlier_val=dict(argstr="-outlier %s %s",),
        prior_4D=dict(
            argstr="-prior4D %s",
            extensions=None,
            mandatory=True,
            xor=["no_prior", "priors"],
        ),
        priors=dict(argstr="%s", mandatory=True, xor=["no_prior", "prior_4D"],),
        reg_val=dict(argstr="-reg %s",),
        relax_priors=dict(argstr="-rf %s %s",),
    )
    inputs = EM.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EM_outputs():
    output_map = dict(
        out_bc_file=dict(extensions=None,),
        out_file=dict(extensions=None,),
        out_outlier_file=dict(extensions=None,),
    )
    outputs = EM.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSCreateLabelMapFromProbabilityMaps


def test_BRAINSCreateLabelMapFromProbabilityMaps_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cleanLabelVolume=dict(argstr="--cleanLabelVolume %s", hash_files=False,),
        dirtyLabelVolume=dict(argstr="--dirtyLabelVolume %s", hash_files=False,),
        environ=dict(nohash=True, usedefault=True,),
        foregroundPriors=dict(argstr="--foregroundPriors %s", sep=",",),
        inclusionThreshold=dict(argstr="--inclusionThreshold %f",),
        inputProbabilityVolume=dict(argstr="--inputProbabilityVolume %s...",),
        nonAirRegionMask=dict(argstr="--nonAirRegionMask %s", extensions=None,),
        priorLabelCodes=dict(argstr="--priorLabelCodes %s", sep=",",),
    )
    inputs = BRAINSCreateLabelMapFromProbabilityMaps.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSCreateLabelMapFromProbabilityMaps_outputs():
    output_map = dict(
        cleanLabelVolume=dict(extensions=None,),
        dirtyLabelVolume=dict(extensions=None,),
    )
    outputs = BRAINSCreateLabelMapFromProbabilityMaps.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import MS_LDA


def test_MS_LDA_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        conform=dict(argstr="-conform",),
        environ=dict(nohash=True, usedefault=True,),
        images=dict(argstr="%s", copyfile=False, mandatory=True, position=-1,),
        label_file=dict(argstr="-label %s", extensions=None,),
        lda_labels=dict(argstr="-lda %s", mandatory=True, sep=" ",),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        shift=dict(argstr="-shift %d",),
        subjects_dir=dict(),
        use_weights=dict(argstr="-W",),
        vol_synth_file=dict(argstr="-synth %s", extensions=None, mandatory=True,),
        weight_file=dict(argstr="-weight %s", extensions=None, mandatory=True,),
    )
    inputs = MS_LDA.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MS_LDA_outputs():
    output_map = dict(
        vol_synth_file=dict(extensions=None,), weight_file=dict(extensions=None,),
    )
    outputs = MS_LDA.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



import os
from .. import get_info
from ..info import get_nipype_gitversion
import pytest


def test_nipype_info():
    exception_not_raised = True
    try:
        get_info()
    except Exception:
        exception_not_raised = False
    assert exception_not_raised


@pytest.mark.skipif(
    not get_nipype_gitversion(),
    reason="not able to get version from get_nipype_gitversion",
)
def test_git_hash():
    # removing the first "g" from gitversion
    get_nipype_gitversion()[1:] == get_info()["commit_hash"]


def _check_no_et():
    import os
    from unittest.mock import patch

    et = os.getenv("NIPYPE_NO_ET") is None

    with patch.dict("os.environ", {"NIPYPE_NO_ET": "1"}):
        from nipype.interfaces.base import BaseInterface

        ver_data = BaseInterface._etelemetry_version_data

    if et and ver_data is None:
        raise ValueError(
            "etelemetry enabled and version data missing - double hits likely"
        )

    return et


def test_no_et(tmp_path):
    from unittest.mock import patch
    from nipype.pipeline import engine as pe
    from nipype.interfaces import utility as niu
    from nipype.interfaces.base import BaseInterface

    et = os.getenv("NIPYPE_NO_ET") is None

    # Pytest doesn't trigger this, so let's pretend it's there
    with patch.object(BaseInterface, "_etelemetry_version_data", {}):

        # Direct function call - environment not set
        f = niu.Function(function=_check_no_et)
        res = f.run()
        assert res.outputs.out == et

        # Basic node - environment not set
        n = pe.Node(
            niu.Function(function=_check_no_et), name="n", base_dir=str(tmp_path)
        )
        res = n.run()
        assert res.outputs.out == et

        # Linear run - environment not set
        wf1 = pe.Workflow(name="wf1", base_dir=str(tmp_path))
        wf1.add_nodes([pe.Node(niu.Function(function=_check_no_et), name="n")])
        res = wf1.run()
        assert next(iter(res.nodes)).result.outputs.out == et

        # MultiProc run - environment initialized with NIPYPE_NO_ET
        wf2 = pe.Workflow(name="wf2", base_dir=str(tmp_path))
        wf2.add_nodes([pe.Node(niu.Function(function=_check_no_et), name="n")])
        res = wf2.run(plugin="MultiProc", plugin_args={"n_procs": 1})
        assert next(iter(res.nodes)).result.outputs.out is False

        # LegacyMultiProc run - environment initialized with NIPYPE_NO_ET
        wf3 = pe.Workflow(name="wf3", base_dir=str(tmp_path))
        wf3.add_nodes([pe.Node(niu.Function(function=_check_no_et), name="n")])
        res = wf3.run(plugin="LegacyMultiProc", plugin_args={"n_procs": 1})
        assert next(iter(res.nodes)).result.outputs.out is False

        # run_without_submitting - environment not set
        wf4 = pe.Workflow(name="wf4", base_dir=str(tmp_path))
        wf4.add_nodes(
            [
                pe.Node(
                    niu.Function(function=_check_no_et),
                    run_without_submitting=True,
                    name="n",
                )
            ]
        )
        res = wf4.run(plugin="MultiProc", plugin_args={"n_procs": 1})
        assert next(iter(res.nodes)).result.outputs.out == et

        # run_without_submitting - environment not set
        wf5 = pe.Workflow(name="wf5", base_dir=str(tmp_path))
        wf5.add_nodes(
            [
                pe.Node(
                    niu.Function(function=_check_no_et),
                    run_without_submitting=True,
                    name="n",
                )
            ]
        )
        res = wf5.run(plugin="LegacyMultiProc", plugin_args={"n_procs": 1})
        assert next(iter(res.nodes)).result.outputs.out == et



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..imagelabelcombine import ImageLabelCombine


def test_ImageLabelCombine_inputs():
    input_map = dict(
        InputLabelMap_A=dict(argstr="%s", extensions=None, position=-3,),
        InputLabelMap_B=dict(argstr="%s", extensions=None, position=-2,),
        OutputLabelMap=dict(argstr="%s", hash_files=False, position=-1,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        first_overwrites=dict(argstr="--first_overwrites ",),
    )
    inputs = ImageLabelCombine.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ImageLabelCombine_outputs():
    output_map = dict(OutputLabelMap=dict(extensions=None, position=-1,),)
    outputs = ImageLabelCombine.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import SegmentCC


def test_SegmentCC_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_inputs=dict(),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-aseg %s", extensions=None, mandatory=True,),
        in_norm=dict(extensions=None, mandatory=True,),
        out_file=dict(
            argstr="-o %s",
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s.auto.mgz",
        ),
        out_rotation=dict(argstr="-lta %s", extensions=None, mandatory=True,),
        subject_id=dict(argstr="%s", mandatory=True, position=-1, usedefault=True,),
        subjects_dir=dict(),
    )
    inputs = SegmentCC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SegmentCC_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), out_rotation=dict(extensions=None,),
    )
    outputs = SegmentCC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Bse


def test_Bse_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        diffusionConstant=dict(argstr="-d %f", usedefault=True,),
        diffusionIterations=dict(argstr="-n %d", usedefault=True,),
        dilateFinalMask=dict(argstr="-p", usedefault=True,),
        edgeDetectionConstant=dict(argstr="-s %f", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        inputMRIFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        noRotate=dict(argstr="--norotate",),
        outputCortexFile=dict(argstr="--cortex %s", extensions=None, hash_files=False,),
        outputDetailedBrainMask=dict(
            argstr="--hires %s", extensions=None, hash_files=False,
        ),
        outputDiffusionFilter=dict(
            argstr="--adf %s", extensions=None, hash_files=False,
        ),
        outputEdgeMap=dict(argstr="--edge %s", extensions=None, hash_files=False,),
        outputMRIVolume=dict(
            argstr="-o %s", extensions=None, genfile=True, hash_files=False,
        ),
        outputMaskFile=dict(
            argstr="--mask %s", extensions=None, genfile=True, hash_files=False,
        ),
        radius=dict(argstr="-r %f", usedefault=True,),
        timer=dict(argstr="--timer",),
        trim=dict(argstr="--trim", usedefault=True,),
        verbosityLevel=dict(argstr="-v %f", usedefault=True,),
    )
    inputs = Bse.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Bse_outputs():
    output_map = dict(
        outputCortexFile=dict(extensions=None,),
        outputDetailedBrainMask=dict(extensions=None,),
        outputDiffusionFilter=dict(extensions=None,),
        outputEdgeMap=dict(extensions=None,),
        outputMRIVolume=dict(extensions=None,),
        outputMaskFile=dict(extensions=None,),
    )
    outputs = Bse.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistLaminarVolumetricLayering


def test_JistLaminarVolumetricLayering_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inInner=dict(argstr="--inInner %s", extensions=None,),
        inLayering=dict(argstr="--inLayering %s",),
        inLayering2=dict(argstr="--inLayering2 %s",),
        inMax=dict(argstr="--inMax %d",),
        inMin=dict(argstr="--inMin %f",),
        inNumber=dict(argstr="--inNumber %d",),
        inOuter=dict(argstr="--inOuter %s", extensions=None,),
        inTopology=dict(argstr="--inTopology %s",),
        incurvature=dict(argstr="--incurvature %d",),
        inpresmooth=dict(argstr="--inpresmooth %s",),
        inratio=dict(argstr="--inratio %f",),
        null=dict(argstr="--null %s",),
        outContinuous=dict(argstr="--outContinuous %s", hash_files=False,),
        outDiscrete=dict(argstr="--outDiscrete %s", hash_files=False,),
        outLayer=dict(argstr="--outLayer %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistLaminarVolumetricLayering.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistLaminarVolumetricLayering_outputs():
    output_map = dict(
        outContinuous=dict(extensions=None,),
        outDiscrete=dict(extensions=None,),
        outLayer=dict(extensions=None,),
    )
    outputs = JistLaminarVolumetricLayering.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSTrimForegroundInDirection


def test_BRAINSTrimForegroundInDirection_inputs():
    input_map = dict(
        BackgroundFillValue=dict(argstr="--BackgroundFillValue %s",),
        args=dict(argstr="%s",),
        closingSize=dict(argstr="--closingSize %d",),
        directionCode=dict(argstr="--directionCode %d",),
        environ=dict(nohash=True, usedefault=True,),
        headSizeLimit=dict(argstr="--headSizeLimit %f",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        otsuPercentileThreshold=dict(argstr="--otsuPercentileThreshold %f",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
    )
    inputs = BRAINSTrimForegroundInDirection.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSTrimForegroundInDirection_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = BRAINSTrimForegroundInDirection.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import PlotTimeSeries


def test_PlotTimeSeries_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", mandatory=True, position=1,),
        labels=dict(argstr="%s",),
        legend_file=dict(argstr="--legend=%s", extensions=None,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, hash_files=False,),
        output_type=dict(),
        plot_finish=dict(argstr="--finish=%d", xor=("plot_range",),),
        plot_range=dict(argstr="%s", xor=("plot_start", "plot_finish"),),
        plot_size=dict(argstr="%s",),
        plot_start=dict(argstr="--start=%d", xor=("plot_range",),),
        sci_notation=dict(argstr="--sci",),
        title=dict(argstr="%s",),
        x_precision=dict(argstr="--precision=%d",),
        x_units=dict(argstr="-u %d", usedefault=True,),
        y_max=dict(argstr="--ymax=%.2f", xor=("y_range",),),
        y_min=dict(argstr="--ymin=%.2f", xor=("y_range",),),
        y_range=dict(argstr="%s", xor=("y_min", "y_max"),),
    )
    inputs = PlotTimeSeries.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PlotTimeSeries_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = PlotTimeSeries.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..nilearn import SignalExtraction


def test_SignalExtraction_inputs():
    input_map = dict(
        class_labels=dict(mandatory=True,),
        detrend=dict(usedefault=True,),
        in_file=dict(extensions=None, mandatory=True,),
        incl_shared_variance=dict(usedefault=True,),
        include_global=dict(usedefault=True,),
        label_files=dict(mandatory=True,),
        out_file=dict(extensions=None, usedefault=True,),
    )
    inputs = SignalExtraction.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SignalExtraction_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SignalExtraction.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import TractographyLabelMapSeeding


def test_TractographyLabelMapSeeding_inputs():
    input_map = dict(
        InputVolume=dict(argstr="%s", extensions=None, position=-2,),
        OutputFibers=dict(argstr="%s", hash_files=False, position=-1,),
        args=dict(argstr="%s",),
        clthreshold=dict(argstr="--clthreshold %f",),
        environ=dict(nohash=True, usedefault=True,),
        inputroi=dict(argstr="--inputroi %s", extensions=None,),
        integrationsteplength=dict(argstr="--integrationsteplength %f",),
        label=dict(argstr="--label %d",),
        maximumlength=dict(argstr="--maximumlength %f",),
        minimumlength=dict(argstr="--minimumlength %f",),
        name=dict(argstr="--name %s",),
        outputdirectory=dict(argstr="--outputdirectory %s", hash_files=False,),
        randomgrid=dict(argstr="--randomgrid ",),
        seedspacing=dict(argstr="--seedspacing %f",),
        stoppingcurvature=dict(argstr="--stoppingcurvature %f",),
        stoppingmode=dict(argstr="--stoppingmode %s",),
        stoppingvalue=dict(argstr="--stoppingvalue %f",),
        useindexspace=dict(argstr="--useindexspace ",),
        writetofile=dict(argstr="--writetofile ",),
    )
    inputs = TractographyLabelMapSeeding.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TractographyLabelMapSeeding_outputs():
    output_map = dict(
        OutputFibers=dict(extensions=None, position=-1,), outputdirectory=dict(),
    )
    outputs = TractographyLabelMapSeeding.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import ComposeXfm


def test_ComposeXfm_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_aff=dict(argstr="-aff %s", extensions=None, mandatory=True,),
        in_df=dict(argstr="-df %s", extensions=None, mandatory=True,),
        out_file=dict(argstr="-out %s", extensions=None, genfile=True,),
    )
    inputs = ComposeXfm.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ComposeXfm_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ComposeXfm.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..svm import SVMTest


def test_SVMTest_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        classout=dict(argstr="-classout",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-testvol %s", extensions=None, mandatory=True,),
        model=dict(argstr="-model %s", mandatory=True,),
        multiclass=dict(argstr="-multiclass %s",),
        nodetrend=dict(argstr="-nodetrend",),
        nopredcensord=dict(argstr="-nopredcensord",),
        num_threads=dict(nohash=True, usedefault=True,),
        options=dict(argstr="%s",),
        out_file=dict(
            argstr="-predictions %s", extensions=None, name_template="%s_predictions",
        ),
        outputtype=dict(),
        testlabels=dict(argstr="-testlabels %s", extensions=None,),
    )
    inputs = SVMTest.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SVMTest_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SVMTest.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistIntensityMp2rageMasking


def test_JistIntensityMp2rageMasking_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inBackground=dict(argstr="--inBackground %s",),
        inMasking=dict(argstr="--inMasking %s",),
        inQuantitative=dict(argstr="--inQuantitative %s", extensions=None,),
        inSecond=dict(argstr="--inSecond %s", extensions=None,),
        inSkip=dict(argstr="--inSkip %s",),
        inT1weighted=dict(argstr="--inT1weighted %s", extensions=None,),
        null=dict(argstr="--null %s",),
        outMasked=dict(argstr="--outMasked_T1_Map %s", hash_files=False,),
        outMasked2=dict(argstr="--outMasked_T1weighted %s", hash_files=False,),
        outSignal=dict(argstr="--outSignal_Proba %s", hash_files=False,),
        outSignal2=dict(argstr="--outSignal_Mask %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistIntensityMp2rageMasking.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistIntensityMp2rageMasking_outputs():
    output_map = dict(
        outMasked=dict(extensions=None,),
        outMasked2=dict(extensions=None,),
        outSignal=dict(extensions=None,),
        outSignal2=dict(extensions=None,),
    )
    outputs = JistIntensityMp2rageMasking.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import TalairachAVI


def test_TalairachAVI_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atlas=dict(argstr="--atlas %s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="--i %s", extensions=None, mandatory=True,),
        out_file=dict(argstr="--xfm %s", extensions=None, mandatory=True,),
        subjects_dir=dict(),
    )
    inputs = TalairachAVI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TalairachAVI_outputs():
    output_map = dict(
        out_file=dict(extensions=None,),
        out_log=dict(extensions=None,),
        out_txt=dict(extensions=None,),
    )
    outputs = TalairachAVI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Eval


def test_Eval_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        expr=dict(argstr='-expr "%s"', mandatory=True, position=3,),
        in_file_a=dict(argstr="-a %s", extensions=None, mandatory=True, position=0,),
        in_file_b=dict(argstr="-b %s", extensions=None, position=1,),
        in_file_c=dict(argstr="-c %s", extensions=None, position=2,),
        num_threads=dict(nohash=True, usedefault=True,),
        other=dict(argstr="", extensions=None,),
        out1D=dict(argstr="-1D",),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file_a",
            name_template="%s_calc",
        ),
        outputtype=dict(),
        single_idx=dict(),
        start_idx=dict(requires=["stop_idx"],),
        stop_idx=dict(requires=["start_idx"],),
    )
    inputs = Eval.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Eval_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Eval.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import DWI2Tensor


def test_DWI2Tensor_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug", position=1,),
        encoding_file=dict(argstr="-grad %s", extensions=None, position=2,),
        environ=dict(nohash=True, usedefault=True,),
        ignore_slice_by_volume=dict(argstr="-ignoreslices %s", position=2, sep=" ",),
        ignore_volumes=dict(argstr="-ignorevolumes %s", position=2, sep=" ",),
        in_file=dict(argstr="%s", mandatory=True, position=-2,),
        out_filename=dict(
            argstr="%s",
            extensions=None,
            name_source="in_file",
            name_template="%s_tensor.mif",
            output_name="tensor",
            position=-1,
        ),
        quiet=dict(argstr="-quiet", position=1,),
    )
    inputs = DWI2Tensor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWI2Tensor_outputs():
    output_map = dict(tensor=dict(extensions=None,),)
    outputs = DWI2Tensor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractCoRegAnatomy


def test_gtractCoRegAnatomy_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        borderSize=dict(argstr="--borderSize %d",),
        convergence=dict(argstr="--convergence %f",),
        environ=dict(nohash=True, usedefault=True,),
        gradientTolerance=dict(argstr="--gradientTolerance %f",),
        gridSize=dict(argstr="--gridSize %s", sep=",",),
        inputAnatomicalVolume=dict(
            argstr="--inputAnatomicalVolume %s", extensions=None,
        ),
        inputRigidTransform=dict(argstr="--inputRigidTransform %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        maxBSplineDisplacement=dict(argstr="--maxBSplineDisplacement %f",),
        maximumStepSize=dict(argstr="--maximumStepSize %f",),
        minimumStepSize=dict(argstr="--minimumStepSize %f",),
        numberOfHistogramBins=dict(argstr="--numberOfHistogramBins %d",),
        numberOfIterations=dict(argstr="--numberOfIterations %d",),
        numberOfSamples=dict(argstr="--numberOfSamples %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTransformName=dict(argstr="--outputTransformName %s", hash_files=False,),
        relaxationFactor=dict(argstr="--relaxationFactor %f",),
        samplingPercentage=dict(argstr="--samplingPercentage %f",),
        spatialScale=dict(argstr="--spatialScale %d",),
        transformType=dict(argstr="--transformType %s",),
        translationScale=dict(argstr="--translationScale %f",),
        useCenterOfHeadAlign=dict(argstr="--useCenterOfHeadAlign ",),
        useGeometryAlign=dict(argstr="--useGeometryAlign ",),
        useMomentsAlign=dict(argstr="--useMomentsAlign ",),
        vectorIndex=dict(argstr="--vectorIndex %d",),
    )
    inputs = gtractCoRegAnatomy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractCoRegAnatomy_outputs():
    output_map = dict(outputTransformName=dict(extensions=None,),)
    outputs = gtractCoRegAnatomy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import HammerAttributeCreator


def test_HammerAttributeCreator_inputs():
    input_map = dict(
        Scale=dict(argstr="--Scale %d",),
        Strength=dict(argstr="--Strength %f",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputCSFVolume=dict(argstr="--inputCSFVolume %s", extensions=None,),
        inputGMVolume=dict(argstr="--inputGMVolume %s", extensions=None,),
        inputWMVolume=dict(argstr="--inputWMVolume %s", extensions=None,),
        outputVolumeBase=dict(argstr="--outputVolumeBase %s",),
    )
    inputs = HammerAttributeCreator.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_HammerAttributeCreator_outputs():
    output_map = dict()
    outputs = HammerAttributeCreator.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import DualRegression


def test_DualRegression_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        con_file=dict(argstr="%s", extensions=None, position=4,),
        des_norm=dict(argstr="%i", position=2, usedefault=True,),
        design_file=dict(argstr="%s", extensions=None, position=3,),
        environ=dict(nohash=True, usedefault=True,),
        group_IC_maps_4D=dict(
            argstr="%s", extensions=None, mandatory=True, position=1,
        ),
        in_files=dict(argstr="%s", mandatory=True, position=-1, sep=" ",),
        n_perm=dict(argstr="%i", mandatory=True, position=5,),
        one_sample_group_mean=dict(argstr="-1", position=3,),
        out_dir=dict(argstr="%s", genfile=True, position=6, usedefault=True,),
        output_type=dict(),
    )
    inputs = DualRegression.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DualRegression_outputs():
    output_map = dict(out_dir=dict(),)
    outputs = DualRegression.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ApplyMask


def test_ApplyMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        invert_xfm=dict(argstr="-invert",),
        keep_mask_deletion_edits=dict(argstr="-keep_mask_deletion_edits",),
        mask_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        mask_thresh=dict(argstr="-T %.4f",),
        out_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=True,
            keep_extension=True,
            name_source=["in_file"],
            name_template="%s_masked",
            position=-1,
        ),
        subjects_dir=dict(),
        transfer=dict(argstr="-transfer %d",),
        use_abs=dict(argstr="-abs",),
        xfm_file=dict(argstr="-xform %s", extensions=None,),
        xfm_source=dict(argstr="-lta_src %s", extensions=None,),
        xfm_target=dict(argstr="-lta_dst %s", extensions=None,),
    )
    inputs = ApplyMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ApplyMask_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ApplyMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
